// +build !pro,!ent

package state

import (
	testing "github.com/mitchellh/go-testing-interface"
)

func TestInitState(t testing.T, state *StateStore) {}
